==> vtigercrm7.1.0rc.tar.gz: vtigercrm/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Products.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'Products'                     => 'Prodotti'                    , 
	'SINGLE_Products'              => 'Prodotto'                    , 
	'LBL_ADD_RECORD'               => 'Aggiungi Prodotto'           , 
	'LBL_RECORDS_LIST'             => 'Products List'               , 
	'LBL_PRODUCT_INFORMATION'      => 'Informazioni Prodotto'       , 
	'LBL_IMAGE_INFORMATION'        => 'Informazioni Immagine Prodotto:', 
	'LBL_STOCK_INFORMATION'        => 'Informazioni Stock:'         , 
	'LBL_MORE_CURRENCIES'          => 'Altre valute'                , 
	'LBL_PRICES'                   => 'Prezzo prodotti'             , 
	'LBL_PRICE'                    => 'Prezzo'                      , 
	'LBL_RESET_PRICE'              => 'Annulla prezzo'              , 
	'LBL_RESET'                    => 'Annulla'                     , 
	'LBL_ADD_TO_PRICEBOOKS'        => 'Add to PriceBooks'           , 
	'Product No'                   => 'No. prodotto'                , 
	'Part Number'                  => 'Numero di serie'             , 
	'Product Active'               => 'Prodotto Attivo'             , 
	'Manufacturer'                 => 'Produttore'                  , 
	'Product Category'             => 'Categoria Prodotto'          , 
	'Website'                      => 'Sito Web'                    , 
	'Mfr PartNo'                   => 'Numero di Serie Produttore'  , 
	'Vendor PartNo'                => 'Numero di Serie Fornitore'   , 
	'Usage Unit'                   => 'Unit&agrave;  Utilizzo'      , 
	'Handler'                      => 'Responsabile'                , 
	'Reorder Level'                => 'Livello Riordino'            , 
	'Tax Class'                    => 'Classe di Tasse'             , 
	'Serial No'                    => 'Numero di Serie'             , 
	'Qty In Stock'                 => 'Quantit&agrave; in Stock'    , 
	'Product Sheet'                => 'Specifiche Prodotto'         , 
	'Qty In Demand'                => 'Quantit&agrave;  in richiesta', 
	'GL Account'                   => 'Codice Contabile'            , 
	'Product Image'                => 'Immagine Prodotto'           , 
	'Unit Price'                   => 'Prezzo Unitario'             , 
	'Commission Rate'              => 'Tasso commissione (%)'       , 
	'Qty/Unit'                     => 'Quantit&agrave;&#47;Unit&agrave;', 
	'--None--'                     => '--Nessuno--'                 , 
	'Hardware'                     => 'Hardware'                    , 
	'Software'                     => 'Software'                    , 
	'CRM Applications'             => 'Applicazioni CRM'            , 
	'300-Sales-Software'           => '300-Vendita-Software'        , 
	'301-Sales-Hardware'           => '301-Vendita-Hardware'        , 
	'302-Rental-Income'            => '302-Noleggi-Software'        , 
	'303-Interest-Income'          => '303-Interessi'               , 
	'304-Sales-Software-Support'   => '304-Vendite-Software-Support', 
	'305-Sales Other'              => '305-Vendite-Altro'           , 
	'306-Internet Sales'           => '306-Vendite-Internet'        , 
	'307-Service-Hardware Labor'   => '307-Servizi-Riparazione-Hardware', 
	'308-Sales-Books'              => '308-Vendite-Libri'           , 
	'Box'                          => 'Box'                         , 
	'Carton'                       => 'Cartone'                     , 
	'Caton'                        => 'Scatola'                     , 
	'Dozen'                        => 'Vetro'                       , 
	'Each'                         => 'Ogni'                        , 
	'Hours'                        => 'Ore'                         , 
	'Impressions'                  => 'Impressioni'                 , 
	'Lb'                           => 'Lb'                          , 
	'M'                            => 'M'                           , 
	'Pack'                         => 'Pacco'                       , 
	'Pages'                        => 'Pagine'                      , 
	'Pieces'                       => 'Pezzi'                       , 
	'Reams'                        => 'Risme'                       , 
	'Sheet'                        => 'Foglio'                      , 
	'Spiral Binder'                => 'Raccoglitore a spirale '     , 
	'Sq Ft'                        => 'Sq Ft'                       , 
	'LBL_CONVERSION_RATE'          => 'Conversion Rate'             , // TODO: Review
    'LBL_PRODUCTSMOD_DISABLED'     => 'Abilita Prodotti Modulo per visualizzare i prodotti',
	'LBL_SHOW_BUNDLE_IN_INVENTORY' => 'Mostra articoli fascio di fattura/Quotes/Sales Order/Ordine di Acquisto',
	'LBL_BUNDLE_TOTAL_COST' => 'Costo totale del Bundle',
	'LBL_UPDATE_BUNDLE_PRICE' => 'Aggiornamento Bundle Prezzo',

  'LBL_PRODUCT_NAME' => 'Nome Del Prodotto',
  'LBL_PRICE_QUANTITY' => 'Prezzo x Quantità',

);

$jsLanguageStrings = array(
	'JS_SUB_PRODUCTS_WILL_BE_SHOWN_IN_INVENTORY' => 'Prodotti Sub verranno visualizzati nell"inventario',
	'JS_SUB_PRODUCTS_WILL_NOT_BE_SHOWN_IN_INVENTORY' => 'Prodotti secondari non verranno visualizzati nell"inventario',
	'JS_SUCCESSFULLY_CHANGED_BUNDLE_COST' => 'Costo totale cambiata con successo del fascio',
	'JS_DELETION_OR_IN_ACTIVATION_CHILD_PRODUCT_MESSAGE' => 'Questo prodotto fa parte di un pacchetto di prodotti. Il prezzo del pacchetto rimane invariato quando un elemento fascio viene eliminato o inattivato. Sei sicuro di voler continuare?',
);

==> vtigercrm7.4.0.tar.gz: vtigercrm/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Products.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'Products'                     => 'Prodotti'                    , 
	'SINGLE_Products'              => 'Prodotto'                    , 
	'LBL_ADD_RECORD'               => 'Aggiungi Prodotto'           , 
	'LBL_RECORDS_LIST'             => 'Lista Prodotti'               , 
	'LBL_PRODUCT_INFORMATION'      => 'Informazioni Prodotto'       , 
	'LBL_IMAGE_INFORMATION'        => 'Informazioni Immagine Prodotto:', 
	'LBL_STOCK_INFORMATION'        => 'Informazioni Magazzino:'         , 
	'LBL_MORE_CURRENCIES'          => 'Altre valute'                , 
	'LBL_PRICES'                   => 'Prezzo prodotti'             , 
	'LBL_PRICE'                    => 'Prezzo'                      , 
	'LBL_RESET_PRICE'              => 'Annulla prezzo'              , 
	'LBL_RESET'                    => 'Annulla'                     , 
	'LBL_ADD_TO_PRICEBOOKS'        => 'Aggiungi ai listini'           , 
	'Product No'                   => 'N. prodotto'                , 
	'Part Number'                  => 'Numero di serie'             , 
	'Product Active'               => 'Prodotto Attivo'             , 
	'Manufacturer'                 => 'Produttore'                  , 
	'Product Category'             => 'Categoria Prodotto'          , 
	'Website'                      => 'Sito Web'                    , 
	'Mfr PartNo'                   => 'Numero di Serie Produttore'  , 
	'Vendor PartNo'                => 'Numero di Serie Fornitore'   , 
	'Usage Unit'                   => 'Unità utilizzata'      , 
	'Handler'                      => 'Responsabile'                , 
	'Reorder Level'                => 'Livello Riordino'            , 
	'Tax Class'                    => 'Classe di Tasse'             , 
	'Serial No'                    => 'Numero di Serie'             , 
	'Qty In Stock'                 => 'Quantità in Stock'    , 
	'Product Sheet'                => 'Specifiche Prodotto'         , 
	'Qty In Demand'                => 'Quantità  in richiesta', 
	'GL Account'                   => 'Codice Contabile'            , 
	'Product Image'                => 'Immagine Prodotto'           , 
	'Unit Price'                   => 'Prezzo Unitario'             , 
	'Commission Rate'              => 'Tasso commissione (%)'       , 
	'Qty/Unit'                     => 'Quantità e Unità', 
	'--None--'                     => '--Nessuno--'                 , 
	'Hardware'                     => 'Hardware'                    , 
	'Software'                     => 'Software'                    , 
	'CRM Applications'             => 'Applicazioni CRM'            , 
	'300-Sales-Software'           => '300-Vendita-Software'        , 
	'301-Sales-Hardware'           => '301-Vendita-Hardware'        , 
	'302-Rental-Income'            => '302-Noleggi-Software'        , 
	'303-Interest-Income'          => '303-Interessi'               , 
	'304-Sales-Software-Support'   => '304-Vendite-Software-Support', 
	'305-Sales Other'              => '305-Vendite-Altro'           , 
	'306-Internet Sales'           => '306-Vendite-Internet'        , 
	'307-Service-Hardware Labor'   => '307-Servizi-Riparazione-Hardware', 
	'308-Sales-Books'              => '308-Vendite-Libri'           , 
	'Box'                          => 'Box'                         , 
	'Carton'                       => 'Cartone'                     , 
	'Caton'                        => 'Scatola'                     , 
	'Dozen'                        => 'Vetro'                       , 
	'Each'                         => 'Ogni'                        , 
	'Hours'                        => 'Ore'                         , 
	'Impressions'                  => 'Impressioni'                 , 
	'Lb'                           => 'Lb'                          , 
	'M'                            => 'M'                           , 
	'Pack'                         => 'Pacco'                       , 
	'Pages'                        => 'Pagine'                      , 
	'Pieces'                       => 'Pezzi'                       , 
	'Reams'                        => 'Risme'                       , 
	'Sheet'                        => 'Foglio'                      , 
	'Spiral Binder'                => 'Raccoglitore a spirale '     , 
	'Sq Ft'                        => 'Sq Ft'                       , 
	'LBL_CONVERSION_RATE'          => 'Tasso di conversione'             , // TODO: Review
    'LBL_PRODUCTSMOD_DISABLED'     => 'Abilita Prodotti per visualizzare i prodotti',
	'LBL_SHOW_BUNDLE_IN_INVENTORY' => 'Mostra articoli Bundle in Fattura/Preventivi/Vendite/Acquisti',
	'LBL_BUNDLE_TOTAL_COST' => 'Costo totale del Bundle',
	'LBL_UPDATE_BUNDLE_PRICE' => 'Aggiornamento Prezzo Bundle',

  'LBL_PRODUCT_NAME' => 'Nome Del Prodotto',
  'LBL_PRICE_QUANTITY' => 'Prezzo x Quantità',

);

$jsLanguageStrings = array(
	'JS_SUB_PRODUCTS_WILL_BE_SHOWN_IN_INVENTORY' => 'Prodotti Sub verranno visualizzati nel\'inventario',
	'JS_SUB_PRODUCTS_WILL_NOT_BE_SHOWN_IN_INVENTORY' => 'Prodotti secondari non verranno visualizzati nell\'inventario',
	'JS_SUCCESSFULLY_CHANGED_BUNDLE_COST' => 'Costo totale cambiata con successo del fascio',
	'JS_DELETION_OR_IN_ACTIVATION_CHILD_PRODUCT_MESSAGE' => 'Questo prodotto fa parte di un pacchetto di prodotti. Il prezzo del pacchetto rimane invariato quando un elemento Bundle viene eliminato o inattivato. Sei sicuro di voler continuare?',
);
